==> openjdk-src-15.0.2.u7-1-aarch64.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_kea.java <==
/*
 * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_kea extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AED", "AED" },
            { "AFN", "AFN" },
            { "ALL", "ALL" },
            { "AMD", "AMD" },
            { "ANG", "ANG" },
            { "AOA", "AOA" },
            { "AUD", "AU$" },
            { "AWG", "AWG" },
            { "AZN", "AZN" },
            { "BAM", "BAM" },
            { "BGN", "BGN" },
            { "BHD", "BHD" },
            { "BIF", "BIF" },
            { "BOB", "BOB" },
            { "BTN", "BTN" },
            { "BWP", "BWP" },
            { "CDF", "CDF" },
            { "CHF", "CHF" },
            { "CVE", "\u200b" },
            { "CZK", "CZK" },
            { "DJF", "DJF" },
            { "DKK", "DKK" },
            { "DZD", "DZD" },
            { "EGP", "EGP" },
            { "ERN", "ERN" },
            { "ETB", "ETB" },
            { "FKP", "FKP" },
            { "GEL", "GEL" },
            { "GMD", "GMD" },
            { "GNF", "GNF" },
            { "GTQ", "GTQ" },
            { "HNL", "HNL" },
            { "HRK", "HRK" },
            { "HTG", "HTG" },
            { "HUF", "HUF" },
            { "IDR", "IDR" },
            { "IQD", "IQD" },
            { "IRR", "IRR" },
            { "ISK", "ISK" },
            { "JOD", "JOD" },
            { "KES", "KES" },
            { "KGS", "KGS" },
            { "KMF", "KMF" },
            { "KPW", "KPW" },
            { "KWD", "KWD" },
            { "LBP", "LBP" },
            { "LKR", "LKR" },
            { "LTL", "LTL" },
            { "LYD", "LYD" },
            { "MAD", "MAD" },
            { "MDL", "MDL" },
            { "MGA", "MGA" },
            { "MKD", "MKD" },
            { "MMK", "MMK" },
            { "MOP", "MOP" },
            { "MRO", "MRO" },
            { "MUR", "MUR" },
            { "MVR", "MVR" },
            { "MWK", "MWK" },
            { "MYR", "MYR" },
            { "MZN", "MZN" },
            { "NIO", "NIO" },
            { "NOK", "NOK" },
            { "NPR", "NPR" },
            { "OMR", "OMR" },
            { "PAB", "PAB" },
            { "PEN", "PEN" },
            { "PGK", "PGK" },
            { "PKR", "PKR" },
            { "PLN", "PLN" },
            { "QAR", "QAR" },
            { "RSD", "RSD" },
            { "RWF", "RWF" },
            { "SAR", "SAR" },
            { "SCR", "SCR" },
            { "SDG", "SDG" },
            { "SEK", "SEK" },
            { "SHP", "SHP" },
            { "SLL", "SLL" },
            { "SOS", "SOS" },
            { "STD", "STD" },
            { "SYP", "SYP" },
            { "SZL", "SZL" },
            { "THB", "\u0e3f" },
            { "TJS", "TJS" },
            { "TMT", "TMT" },
            { "TND", "TND" },
            { "TOP", "TOP" },
            { "TZS", "TZS" },
            { "UGX", "UGX" },
            { "UZS", "UZS" },
            { "VEF", "VEF" },
            { "VUV", "VUV" },
            { "WST", "WST" },
            { "YER", "YER" },
            { "ZAR", "ZAR" },
            { "ZMW", "ZMW" },
            { "aed", "Diren di Emiradus Arabi Unidu" },
            { "aoa", "Kuanza" },
            { "aud", "Dola australianu" },
            { "bhd", "Dinar di Barain" },
            { "bif", "Franku borundes" },
            { "brl", "Rial brazileru" },
            { "bwp", "Pula di Botsuana" },
            { "cad", "Dola kanadianu" },
            { "cdf", "Franku kongoles" },
            { "chf", "Franku suisu" },
            { "cny", "Iuan xines" },
            { "cve", "Skudu Kabuverdianu" },
            { "djf", "Franku di Djibuti" },
            { "dkk", "Kuroa dinamarkeza" },
            { "dzd", "Dinar arjelinu" },
            { "egp", "Libra ej\u00edpsiu" },
            { "ern", "Nafka di Eritreia" },
            { "etb", "Bir eti\u00f3piku" },
            { "eur", "Euro" },
            { "gbp", "Libra brit\u00e1niku" },
            { "ghc", "Sedi di Gana (1979\u20132007)" },
            { "gmd", "Dalasi" },
            { "gns", "Sili" },
            { "hkd", "Dola di Ong Kong" },
            { "idr", "Rupia indoneziu" },
            { "inr", "Rupia indianu" },
            { "jpy", "Ieni japones" },
            { "kes", "Xelin kenianu" },
            { "kmf", "Franku di Komoris" },
            { "krw", "Won sul-koreanu" },
            { "lrd", "Dola liberianu" },
            { "lsl", "Loti di Lezotu" },
            { "lyd", "Dinar l\u00edbiu" },
            { "mad", "Diren marokinu" },
            { "mga", "Ariari di Madagaskar" },
            { "mro", "Ougia (1973\u20132017)" },
            { "mru", "Ougia" },
            { "mur", "Rupia di Maurisias" },
            { "mwk", "Kuaxa di Malaui" },
            { "mxn", "Pezu mexikanu" },
            { "mzm", "Metikal" },
            { "nad", "Dola namibianu" },
            { "ngn", "Naira" },
            { "nok", "Kuroa norueges" },
            { "pln", "Zloty polaku" },
            { "rub", "Rublu rusu" },
            { "rwf", "Franku ruandes" },
            { "sar", "Rial saudita" },
            { "scr", "Rupia di Seixelis" },
            { "sdg", "Libra sudanes" },
            { "sdp", "Libra sudanes antigu (1957\u20131998)" },
            { "sek", "Kuroa sueku" },
            { "shp", "Libra di Santa Ilena" },
            { "sll", "Leone di Sera Leoa" },
            { "sos", "Xelin somalianu" },
            { "std", "Dobra di S\u00e3u Tume i Pr\u00ednsipi (1977\u20132017)" },
            { "stn", "Dobra di San Tume i Pr\u00ednsipi" },
            { "szl", "Lilanjeni" },
            { "thb", "Baht tailandes" },
            { "tnd", "Dinar tunizianu" },
            { "try", "Lira turku" },
            { "twd", "Dola Novu di Taiwan" },
            { "tzs", "Xelin di Tanzania" },
            { "ugx", "Xelin ugandensi" },
            { "usd", "Dola merkanu" },
            { "xaf", "Franku CFA (BEAC)" },
            { "xof", "Franku CFA (BCEAO)" },
            { "xxx", "Mueda diskonxedu" },
            { "zar", "Rand sulafrikanu" },
            { "zmk", "Kuaxa zambianu (1968\u20132012)" },
            { "zmw", "Kuaxa zambianu" },
            { "zwd", "Dola di Zimbabue (1980\u20132008)" },
        };
        return data;
    }
}

==> openjdk-src-21.0.2.u13-3-aarch64.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_kea.java <==
/*
 * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_kea extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AED", "AED" },
            { "AFN", "AFN" },
            { "ALL", "ALL" },
            { "AMD", "AMD" },
            { "ANG", "ANG" },
            { "AOA", "AOA" },
            { "AUD", "AU$" },
            { "AWG", "AWG" },
            { "AZN", "AZN" },
            { "BAM", "BAM" },
            { "BGN", "BGN" },
            { "BHD", "BHD" },
            { "BIF", "BIF" },
            { "BOB", "BOB" },
            { "BTN", "BTN" },
            { "BWP", "BWP" },
            { "CDF", "CDF" },
            { "CHF", "CHF" },
            { "CVE", "\u200b" },
            { "CZK", "CZK" },
            { "DJF", "DJF" },
            { "DKK", "DKK" },
            { "DZD", "DZD" },
            { "EGP", "EGP" },
            { "ERN", "ERN" },
            { "ETB", "ETB" },
            { "FKP", "FKP" },
            { "GEL", "GEL" },
            { "GMD", "GMD" },
            { "GNF", "GNF" },
            { "GTQ", "GTQ" },
            { "HNL", "HNL" },
            { "HRK", "HRK" },
            { "HTG", "HTG" },
            { "HUF", "HUF" },
            { "IDR", "IDR" },
            { "IQD", "IQD" },
            { "IRR", "IRR" },
            { "ISK", "ISK" },
            { "JOD", "JOD" },
            { "KES", "KES" },
            { "KGS", "KGS" },
            { "KMF", "KMF" },
            { "KPW", "KPW" },
            { "KWD", "KWD" },
            { "LBP", "LBP" },
            { "LKR", "LKR" },
            { "LTL", "LTL" },
            { "LYD", "LYD" },
            { "MAD", "MAD" },
            { "MDL", "MDL" },
            { "MGA", "MGA" },
            { "MKD", "MKD" },
            { "MMK", "MMK" },
            { "MOP", "MOP" },
            { "MRO", "MRO" },
            { "MUR", "MUR" },
            { "MVR", "MVR" },
            { "MWK", "MWK" },
            { "MYR", "MYR" },
            { "MZN", "MZN" },
            { "NIO", "NIO" },
            { "NOK", "NOK" },
            { "NPR", "NPR" },
            { "OMR", "OMR" },
            { "PAB", "PAB" },
            { "PEN", "PEN" },
            { "PGK", "PGK" },
            { "PKR", "PKR" },
            { "PLN", "PLN" },
            { "QAR", "QAR" },
            { "RSD", "RSD" },
            { "RWF", "RWF" },
            { "SAR", "SAR" },
            { "SCR", "SCR" },
            { "SDG", "SDG" },
            { "SEK", "SEK" },
            { "SHP", "SHP" },
            { "SLL", "SLL" },
            { "SOS", "SOS" },
            { "STD", "STD" },
            { "SYP", "SYP" },
            { "SZL", "SZL" },
            { "THB", "\u0e3f" },
            { "TJS", "TJS" },
            { "TMT", "TMT" },
            { "TND", "TND" },
            { "TOP", "TOP" },
            { "TZS", "TZS" },
            { "UGX", "UGX" },
            { "UZS", "UZS" },
            { "VEF", "VEF" },
            { "VUV", "VUV" },
            { "WST", "WST" },
            { "YER", "YER" },
            { "ZAR", "ZAR" },
            { "ZMW", "ZMW" },
            { "aed", "Diren di Emiradus Arabi Unidu" },
            { "aoa", "Kuanza" },
            { "aud", "Dola australianu" },
            { "bhd", "Dinar di Barain" },
            { "bif", "Franku borundes" },
            { "brl", "Rial brazileru" },
            { "bwp", "Pula di Botsuana" },
            { "cad", "Dola kanadianu" },
            { "cdf", "Franku kongoles" },
            { "chf", "Franku suisu" },
            { "cny", "Iuan xines" },
            { "cve", "Skudu Kabuverdianu" },
            { "djf", "Franku di Djibuti" },
            { "dkk", "Kuroa dinamarkeza" },
            { "dzd", "Dinar arjelinu" },
            { "egp", "Libra ej\u00edpsiu" },
            { "ern", "Nafka di Eritreia" },
            { "etb", "Bir eti\u00f3piku" },
            { "eur", "euro" },
            { "gbp", "Libra brit\u00e1niku" },
            { "ghc", "Sedi di Gana (1979\u20132007)" },
            { "gmd", "Dalasi" },
            { "gns", "Sili" },
            { "hkd", "Dola di Ong Kong" },
            { "idr", "Rupia indoneziu" },
            { "inr", "Rupia indianu" },
            { "jpy", "Ieni japones" },
            { "kes", "Xelin kenianu" },
            { "kmf", "Franku di Komoris" },
            { "krw", "Won sul-koreanu" },
            { "lrd", "Dola liberianu" },
            { "lsl", "Loti di Lezotu" },
            { "lyd", "Dinar l\u00edbiu" },
            { "mad", "Diren marokinu" },
            { "mga", "Ariari di Madagaskar" },
            { "mro", "Ougia (1973\u20132017)" },
            { "mru", "Ougia" },
            { "mur", "Rupia di Maurisias" },
            { "mwk", "Kuaxa di Malaui" },
            { "mxn", "Pezu mexikanu" },
            { "mzm", "Metikal" },
            { "nad", "Dola namibianu" },
            { "ngn", "Naira" },
            { "nok", "Kuroa norueges" },
            { "pln", "Zloty polaku" },
            { "rub", "Rublu rusu" },
            { "rwf", "Franku ruandes" },
            { "sar", "Rial saudita" },
            { "scr", "Rupia di Seixelis" },
            { "sdg", "Libra sudanes" },
            { "sdp", "Libra sudanes antigu (1957\u20131998)" },
            { "sek", "Kuroa sueku" },
            { "shp", "Libra di Santa Ilena" },
            { "sll", "Leone di Sera Leoa" },
            { "sos", "Xelin somalianu" },
            { "std", "Dobra di San Tume i Pr\u00ednsipi (1977\u20132017)" },
            { "stn", "Dobra di San Tume i Pr\u00ednsipi" },
            { "szl", "Lilanjeni" },
            { "thb", "Baht tailandes" },
            { "tnd", "Dinar tunizianu" },
            { "try", "Lira turku" },
            { "twd", "Dola Novu di Taiwan" },
            { "tzs", "Xelin di Tanz\u00e1nia" },
            { "ugx", "Xelin ugandensi" },
            { "usd", "Dola merkanu" },
            { "xaf", "Franku CFA (BEAC)" },
            { "xof", "Franku CFA (BCEAO)" },
            { "xxx", "Mueda diskonxedu" },
            { "zar", "Rand sulafrikanu" },
            { "zmk", "Kuaxa zambianu (1968\u20132012)" },
            { "zmw", "Kuaxa zambianu" },
            { "zwd", "Dola di Zimbabue (1980\u20132008)" },
        };
        return data;
    }
}
